==> haskell-vector-algorithms-0.8.0.4-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-algorithms
version:              0.8.0.4
visibility:           public
id:                   vector-algorithms-0.8.0.4-KmVJfGMzZ6L90Xv83v3kIe
key:                  vector-algorithms-0.8.0.4-KmVJfGMzZ6L90Xv83v3kIe
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  d687ccb39701f88073401368abd072df
exposed:              True
exposed-modules:
    Data.Vector.Algorithms.AmericanFlag Data.Vector.Algorithms.Heap
    Data.Vector.Algorithms.Insertion Data.Vector.Algorithms.Intro
    Data.Vector.Algorithms.Merge Data.Vector.Algorithms.Optimal
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-algorithms-0.8.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-algorithms-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/vector-algorithms-0.8.0.4
hs-libraries:         HSvector-algorithms-0.8.0.4-KmVJfGMzZ6L90Xv83v3kIe
include-dirs:
    /usr/lib/ghc-9.0.2/site-local/vector-algorithms-0.8.0.4/include

depends:
    base-4.15.1.0 bytestring-0.10.12.1
    primitive-0.7.3.0-DAPJLCmVTUi8ENwml4mUVr
    vector-0.12.3.1-3D3Ad9qttllIejNhiZMcEI

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.8.0.4-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-algorithms
version:              0.8.0.4
visibility:           public
id:                   vector-algorithms-0.8.0.4-A5tngsM8nh87XSa1QHnwAg
key:                  vector-algorithms-0.8.0.4-A5tngsM8nh87XSa1QHnwAg
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  f62f797b15adf50447ca1593381617a3
exposed:              True
exposed-modules:
    Data.Vector.Algorithms.AmericanFlag Data.Vector.Algorithms.Heap
    Data.Vector.Algorithms.Insertion Data.Vector.Algorithms.Intro
    Data.Vector.Algorithms.Merge Data.Vector.Algorithms.Optimal
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-algorithms-0.8.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-algorithms-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/vector-algorithms-0.8.0.4
hs-libraries:         HSvector-algorithms-0.8.0.4-A5tngsM8nh87XSa1QHnwAg
include-dirs:
    /usr/lib/ghc-9.0.2/site-local/vector-algorithms-0.8.0.4/include

depends:
    base-4.15.1.0 bytestring-0.10.12.1
    primitive-0.7.3.0-54yhKl7GYKVF2i3EyCYoxq
    vector-0.12.3.1-FGR30quEvBKIVgcX0eclul

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
